var EngineBaySection = function(game_state){
	this.grabs_input = true
	this.game_state = game_state
	this.num_missing_parts = 0
}
EngineBaySection.prototype = {
	on_init: function(){
		this.base = game.add.group()

		this.engine_bay = generate_engine_bay(game, this.base, this.game_state,
				this.game_state.customer.broken_partname, {
			on_click_part: this.on_click_part.bind(this),
		})
		this.base.add(this.engine_bay)
		this.game_state.engine_bay = this.engine_bay

		this.removed_parts = game.add.group()
		this.base.add(this.removed_parts)

		this.ui_layer = game.add.group()
		this.base.add(this.ui_layer)
		game.world.bringToTop(this.ui_layer)

		var style = {
			fontSize: COST_FONT_SIZE,
			fill: "#cb740e",
			stroke: "#1e1e1e",
			strokeThickness: 1,
			wordWrap: true,
			wordWrapWidth: 770,
		}
		this.ui_text = game.add.text(950, 0, "Foo", style)
		this.ui_layer.add(this.ui_text)

		var style = {
			fontSize: COST_FONT_SIZE,
			fill: "#cb740e",
			stroke: "#1e1e1e",
			strokeThickness: 1,
			wordWrap: true,
			wordWrapWidth: 770,
		}
		var lib = part_library[this.game_state.customer.broken_partname]
		var text = "Fix \""+lib.what+"\""
		this.ui_text2 = game.add.text(512, 700-style.fontSize, text, style)
		this.ui_text2.anchor.x = Math.round(this.ui_text2.width * 0.5) / this.ui_text2.width;
		this.ui_layer.add(this.ui_text2)

		this.button = game.add.button(1000-34, 600-32, "continue_button", function(){
			this.on_press_next()
		}, this, 2, 1, 0)
		this.ui_layer.add(this.button)
		this.button.events.onInputOver.add(function(){
			this.button.tint = 0x88ff88
		}, this)
		this.button.events.onInputOut.add(function(){
			this.button.tint = 0xffffff
		}, this)

		this.on_bill_changed()

		add_statusbar(this.base, this.game_state)
	},
	on_remove: function(){
		this.base.destroy()
	},
	on_click_part: function(part){
		if(part.removed_by_player)
			return
		var partname = part.key.replace(/^part_/, "")
		var lib = part_library[partname]
		console.log("Removing part", partname)
		part.tint = 0xff0000
		part.removed_by_player = true
		part.inputEnabled = false
		part.tip.destroy()

		choose_random(sounds.ratchet).play()

		setTimeout(function(){
			choose_random(sounds.clank).play()
		}, Math.random() * 500)

		this.num_missing_parts++
		this.game_state.current_procedure.push({
			action: "remove",
			partname: partname,
		})
		this.game_state.current_work_cost += lib.work
		this.game_state.current_material_cost += lib.material
		this.on_bill_changed()

		// Make this part rarer
		this.game_state.make_part_rarer(partname)

		var removed_part = this.removed_parts.create(
			part.position.x,
			part.position.y,
			part.key)
		removed_part.tint = 0x88ff88
		removed_part.original_part = part
		removed_part.inputEnabled = true
		removed_part.input.useHandCursor = true
		removed_part.events.onInputOver.add(function(){
			if(!removed_part.replaced_by_player)
				removed_part.tint = 0x00ff00
			//console.log(removed_part_library[removed_part.key.replace(/^removed_part_/, "")])
		}, this)
		removed_part.events.onInputOut.add(function(){
			if(!removed_part.replaced_by_player)
				removed_part.tint = 0x88ff88
		}, this)
		removed_part.events.onInputUp.add(function(){
			console.log("Re-installing part", partname)
			removed_part.tint = 0xffffff
			removed_part.replaced_by_player = true
			var tween = game.add.tween(removed_part).to({x: part.position.x}, 200,
					Phaser.Easing.Sinusoidal.Out)
			tween.onComplete.add(function(){
				removed_part.destroy()
				part.tint = 0x88ff88
				add_part_tooltip(game, part)
				part.input.useHandCursor = false

				choose_random(sounds.ratchet).play()
			})
			tween.start()

			choose_random(sounds.clank).play()

			this.num_missing_parts--
			this.game_state.current_procedure.push({
				action: "install",
				partname: partname,
			})
			this.on_bill_changed()
		}, this)
		var tween = game.add.tween(removed_part).to({y: -200}, 200,
				Phaser.Easing.Sinusoidal.Out, true, 100)
		tween.onComplete.add(function(){
			removed_part.position.x = 900
			removed_part.position.y = part.y - 50
		})
		tween.start()
	},
	on_bill_changed: function(){
		/*var text = "Parts: "+this.game_state.current_material_cost+" €\n"+
				"Work: "+this.game_state.current_work_cost+" €\n"*/
		var text = "Parts: "+this.game_state.current_material_cost+" €\n"+
				"Billed: "+(this.game_state.current_material_cost+this.game_state.current_work_cost)+" €\n"
		this.ui_text.text = text

		if(this.num_missing_parts == 0 && this.game_state.current_material_cost > 0)
			this.button.visible = true
		else
			this.button.visible = false
	},
	on_press_next: function(){
		this.game_state.cars_fixed++

		if(this.game_state.known_procedures[this.game_state.customer.broken_partname] === undefined){
			sections.push(new ProcedureSection(this.game_state, this.game_state.current_procedure, function(){
				sections.push(new PostDiscussWithCustomerSection(this.game_state))
			}))
		} else {
			sections.push(new CompareProcedureSection(this.game_state))
		}
	},
}
